% ReduceBoth 01-Apr-2020 

% read in "both" spatial survey data and timeseries data
% do various stages of data reduction
% create one file all downstream modules will use

% n.b. this is long, with multiple parts, and slow to run

% There are 7 sections, as follows:
% STAGE 1 - Get spatial survey data and create WCOL and STN tables
% STAGE 2 - Create DIST table and aux (readme)
% STAGE 3 - Get time series data, put it in "TimSer"
% STAGE 4 - Compute summary stats and ranks
% STAGE 5 - Group survey stations greater/less than 4 m deep
% STAGE 6 - Add daily-resolution time series
% STAGE 7 - Add "percent hypoxic area"

% see "readme" at bottom, for concise descriptions of all results

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

% tidy up
clear runname diaryname def ingrps adm;

%% STAGE 1 - Get spatial survey data and create WCOL and STN tables

% From spreadsheet of all profiles ('raw') provided by Warren, extract and
%   save to a mat file two summary tables.

% One Table "WCOL" has the following columns:
%       Date,Time,StnCode,zmin,zmax, and each of the following
%           (column names use OC = oxy conc, OP = oxy pct sat)
%       "DO conc bott", "DO conc min", "z DO conc min"
%       "DO pct bott", "DO pct min", "z DO pct min"
%       "CHL surf", "CHL max", "z CHL max"
%       "TEMP max", "z TEMP max", "TEMP min", "z TEMP min" 
%           "surf TEMP", "bott TEMP", "del TEMP"
%       "SAL max", "z SAL max", "SAL min", "z SAL min" 
%           "surf SAL", "bott SAL", "del SAL"
%       "SGMA max", "z SGMA max", "SGMA min", "z SGMA min" 
%           "surf SGMA", "bott SGMA", "del SGMA"
%
% Note: The time values are the median of the times measured during the
%   profile/cast.
%
% The second table "STN", generated mostly using WCOL, has these columns:
%       StnCode, Lat, Lon, zmaxMin, zmaxMedn, zmaxMax, zmaxStd, zBathy 
%   where zBathy is from an independent topographic dataset.
%
% !! n.b. there are no NaNs in the resulting tables EXCEPT the following:
%   In WCOL at 11 stns on 07/23/2014, all DO (conc & pct sat) are NaN:
%       EPS01, UPB01, WPS01/02/04/05/07/08/09/13/14

fprintf('STAGE 1/7\n');
% read data in
fprintf('reading data in\n');
warning('off','MATLAB:table:ModifiedAndSavedVarnames');
dat = readtable(in.srvfil);
warning('on','MATLAB:table:ModifiedAndSavedVarnames');
nrow = length(dat.Date);

% CORRECTIONS TO THE ASCII FILE WARREN GAVE ME (slow)
% (yes this certainly could be coded much more efficiently!)
fprintf('making corrections to data\n');
for i = 1:nrow
    if mod(i,5000)==1
        fprintf('  %d of %d\n',i,length(dat.Date));
    end
    % correct times that are "13" (but should be 13:00)
    if isempty(strfind(dat.Time{i},':'))
        new = [ dat.Time{i} ':00'];
        fprintf('  i=%d replacing %s with %s\n',i,dat.Time{i},new);
        dat.Time{i} = new;
        clear new;
    end
    % correct years that are YY (unlike all others which are YYYY)
    [yr,mon,day] = datevec(dat.Date(i));
    if yr < 1900
        new = datetime(yr+2000,mon,day);
        new.Format = 'MM/dd/uuuu';
        fprintf('  i=%d replacing %s with %s\n',i,dat.Date(i),new);
        dat.Date(i) = new;
        clear new;
    end
    clear yr mon day;
    % replace erroneous "BBT3 " with "BBT3"
    if strcmp(dat.Station{i},'BBT3 ')
        new = 'BBT3';
        fprintf('  i=%d replacing "%s" with "%s"\n',i,dat.Station{i},new);
        dat.Station{i} = new;
        clear new
    end
    % replace erroneous "ESP01" with "EPS01"
    if strcmp(dat.Station{i},'ESP01')
        new = 'EPS01';
        fprintf('  i=%d replacing %s with %s\n',i,dat.Station{i},new);
        dat.Station{i} = new;
        clear new;
    end
    % replace erroneous 'UPB 10' with 'UPB10'
    if strcmp(dat.Station{i},'UPB 10')
        new = 'UPB10';
        fprintf('  i=%d replacing %s with %s\n',i,dat.Station{i},new);
        dat.Station{i} = new;
        clear new;
    end
end
clear i nrow;

% make list of unique stations
stnlst = unique(dat.Station);
nstn = length(stnlst);

% make list of unique dates
datelst = unique(dat.Date);
ndate = length(datelst);

% Create the WCOL table (and lat-lon values, for STN table later)
% for each unique date-stn combination add a row to table
fprintf('creating WCOL table\n');
alllat = nan*ones(nstn,1);
alllon = nan*ones(nstn,1);
for idate = 1:ndate
    for istn = 1:nstn
        fprintf('  working on date %d of %d, station %d of %d\n',...
            idate,ndate,istn,nstn);
        ind = find(dat.Date == datelst(idate) & ...
                    strcmp(dat.Station,stnlst(istn)));
        if length(ind)
            % get lat and lon
            alllat(istn) = dat.Lat(ind(1));
            alllon(istn) = dat.Lon(ind(1));
            % get profile data and calculate needed variables from it
            z = dat.Depth_m_(ind);
            zmin = min(z);
            zmax = max(z);
            % TEMP
            TEMP = dat.Temp_degC_(ind);
            TEMPzmin = mean(TEMP(find(z==zmin)));
            TEMPmin = min(TEMP);
            zTEMPmin = mean(z(find(TEMP==TEMPmin)));
            TEMPzmax = mean(TEMP(find(z==zmax)));
            TEMPmax = max(TEMP);
            zTEMPmax = mean(z(find(TEMP==TEMPmax)));
            delTEMP = TEMPmax-TEMPmin;
            clear TEMP;
            % SAL
            SAL = dat.Salinity_ppt_(ind);
            SALzmin = mean(SAL(find(z==zmin)));
            SALmin = min(SAL);
            zSALmin = mean(z(find(SAL==SALmin)));
            SALzmax = mean(SAL(find(z==zmax)));
            SALmax = max(SAL);
            zSALmax = mean(z(find(SAL==SALmax)));
            delSAL = SALmax-SALmin;
            clear SAL;
            % SGMA
            SGMA = dat.Density_sigmaT_(ind);
            SGMAzmin = mean(SGMA(find(z==zmin)));
            SGMAmin = min(SGMA);
            zSGMAmin = mean(z(find(SGMA==SGMAmin)));
            SGMAzmax = mean(SGMA(find(z==zmax)));
            SGMAmax = max(SGMA);
            zSGMAmax = mean(z(find(SGMA==SGMAmax)));
            delSGMA = SGMAmax-SGMAmin;
            clear SGMA;
            % OC = oxy conc (mg/l)
            OC = dat.DO_mg_l_(ind); 
            OC = OC(OC~=999);
            if length(OC)
                whr = find(z==zmax);
                if ~isempty(OC(whr))
                    OCzmax = mean(OC(whr));
                else
                    OCzmax = nan;
                end
                OCmin = min(OC);
                zOCmin = mean(z(find(OC==OCmin)));
                clear whr;
            else
                OCzmax = nan;
                OCmin = nan;
                zOCmin = nan;
            end
            clear OC;
            % OP = oxy pct sat
            OP = dat.DO__Sat_(ind);
            OP = OP(OP~=999);
            if length(OP)
                whr = find(z==zmax);
                if ~isempty(OP(whr))
                    OPzmax = mean(OP(whr));
                else
                    OPzmax = nan;
                end
                OPmin = min(OP);
                zOPmin = mean(z(find(OP==OPmin)));
                clear whr;
            else
                OPzmax = nan;
                OPmin = nan;
                zOPmin = nan;
            end
            clear OP;
            % CHL 
            CHL = dat.ChlorophyllCalibrated_ug_L_(ind);
            CHLzmin = mean(CHL(find(z==zmin)));
            CHLmax = max(CHL);
            zCHLmax = mean(z(find(CHL==CHLmax)));
            clear CHL;
            % create new row for table
            Tnew = table(datelst(idate),dat.Time(round(median(ind))),...
                    stnlst(istn),zmin,zmax,OCzmax,OCmin,zOCmin,...
                    OPzmax,OPmin,zOPmin,CHLzmin,CHLmax,zCHLmax,...
                    TEMPzmin,TEMPzmax,...
                            TEMPmin,zTEMPmin,TEMPmax,zTEMPmax,delTEMP,...
                    SALzmin,SALzmax,...
                            SALmin,zSALmin,SALmax,zSALmax,delSAL,...
                    SGMAzmin,SGMAzmax,...
                            SGMAmin,zSGMAmin,SGMAmax,zSGMAmax,delSGMA,...                    
                'VariableNames',{'Date','Time','Stn','zmin','zmax',...
                    'OCzmax','OCmin','zOCmin','OPzmax','OPmin','zOPmin',...
                    'CHLzmin','CHLmax','zCHLmax',...
                    'TEMPzmin','TEMPzmax',...
                    'TEMPmin','zTEMPmin','TEMPmax','zTEMPmax','delTEMP',...
                    'SALzmin','SALzmax',...
                    'SALmin','zSALmin','SALmax','zSALmax','delSAL',...
                    'SGMAzmin','SGMAzmax',...
                    'SGMAmin','zSGMAmin','SGMAmax','zSGMAmax','delSGMA'});
            clear ind z zmin zmax OCzmax OCmin zOCmin OPzmax OPmin zOPmin;
            clear CHLzmin CHLmax zCHLmax;
            clear TEMPzmin TEMPzmax;
            clear TEMPmin zTEMPmin TEMPmax zTEMPmax delTEMP;
            clear SALzmin SALzmax;
            clear SALmin zSALmin SALmax zSALmax delSAL;
            clear SGMAzmin SGMAzmax;
            clear SGMAmin zSGMAmin SGMAmax zSGMAmax delSGMA;
            if exist('T')
                % append new row to table
                T = [T;Tnew];
            else
                % table doesn't exist, create it with this new row
                T = Tnew;
            end
            clear Tnew;
        end
    end
    clear istn;
end
clear idate dat;
WCOL = T;
clear T;

% Compute zBathy for each station
b = load(in.bathyfil);
allzBathy = nan*ones(nstn,1);
for istn = 1:nstn
    allzBathy(istn) = -round(interp2(b.lon,flipud(b.lat),b.z,...
        alllon(istn),alllat(istn)),1);
end
clear b;

% Now create Table STN
fprintf('creating STN table\n');
for istn = 1:nstn
    fprintf('  working on stn %s\n',stnlst{istn});
    ind = find(strcmp(WCOL.Stn,stnlst{istn}));
    allmaxz = table2array(WCOL(ind,{'zmax'}));
    zmaxMedn = nanmedian(allmaxz);
    zmaxStd = nanstd(allmaxz);
    zmaxMin = nanmin(allmaxz);
    zmaxMax = nanmax(allmaxz);
    zBathy = allzBathy(istn);
    Stn = stnlst(istn);
    Lat = alllat(istn);
    Lon = alllon(istn);
    Tnew = table(Stn,Lat,Lon,zmaxMin, zmaxMedn, zmaxMax, zmaxStd, zBathy);
    clear ind allmaxz zmax* zBathy Stn Lat Lon;
    if exist('T')
        % append new row to table
        T = [T;Tnew];
    else
        % table doesn't exist, create it with this new row
        T = Tnew;
    end
    clear Tnew;
end
clear istn alllat alllon allzBathy;
STN = T;
clear T;

% clear all but WCOL, STN, in
clear datelst ndate nstn stnlst; 

%% STAGE 2 - Create DIST table and aux (readme)
% using WCOL and STN tables, 
%      first, drop the UBP-NP station because it was sampled only once
% then, group in xy (groups of stations -- grplst) 
%       and group in t (groups of times -- srvlst)
% and compute DIST (inter-station distances)

fprintf('STAGE 2/7\n');
% drop UPB-NP
ind = find(~strcmp(WCOL.Stn,'UPB-NP'));
WCOL = WCOL(ind,:);
ind = find(~strcmp(STN.Stn,'UPB-NP'));
STN = STN(ind,:);
clear ind;

% groupings
srvlst = unique(WCOL.Date);
stnlst = STN.Stn;
nstn = length(stnlst);

% define list of stngrps, roughly in order from north to south
grpnam = {'SR';'PRN';'PRC';'PRT';'PRS';'BRT';'UPB';'BBT';'GRB';...
    'WPS';'EPN';'BH';'RWU';'EPS';};
ngrp = length(grpnam);

% for each stngrp create list of stations
grplst = cell(ngrp,1);
maxgrplen = 0;
for igrp = 1:ngrp
    nchr = length(grpnam{igrp});
    ind = [];
    for istn = 1:nstn
        if strcmp(stnlst{istn}(1:nchr),grpnam{igrp}(1:nchr))
            ind = [ind istn];
        end
    end
    clear istn;
    grplst{igrp} = stnlst(ind)';
    if length(grplst{igrp}) > maxgrplen
        maxgrplen = length(grplst{igrp});
    end
    clear ind;
end
clear igrp nchr;

% calculate distances between survey stations
DIST = table(STN.Stn);
clat = mean(STN.Lat);
cs = cos(clat*pi/180);
kpd = 111.120; % distances in km
for istn = 1:nstn
    dist = nan*ones(nstn,1);
    for jstn = 1:nstn 
        dist(jstn) = sqrt( ((STN.Lon(istn)-STN.Lon(jstn))*cs*kpd)^2 + ...
                        ((STN.Lat(istn)-STN.Lat(jstn))*kpd)^2);
    end
    eval(sprintf('DIST.%s = dist;',STN.Stn{istn}));
    clear dist;
end
% now add columns for the fixed site stations
fstn = load(in.fstnfil);
[~,FStnInd11] = ismember(fstn.SiteAbbr,in.fstnlst);
ind = [];
for i = 1:length(in.fstnlst)
    ind = [ind find(FStnInd11==i)];
end
clear i;
FStn = fstn.SiteAbbr(ind);
FLat = fstn.lat(ind);
FLon = fstn.lon(ind);
nfstn = length(ind);
clear fstn FStnInd11 ind;
for ifstn = 1:nfstn
    dist = nan*ones(nstn,1);
    for jstn = 1:nstn 
        dist(jstn) = sqrt( ((FLon(ifstn)-STN.Lon(jstn))*cs*kpd)^2 + ...
                        ((FLat(ifstn)-STN.Lat(jstn))*kpd)^2);
    end
    eval(sprintf('DIST.%s = dist;',FStn{ifstn}));
    clear dist;
end
clear istn ifstn nchr jstn kpd clat cs ind FLat FLon FStn;
   
aux.srvlst = srvlst;
aux.grplst = grplst;
aux.grpnam = grpnam;
aux.fstnlst = in.fstnlst;

DIST.Properties.VariableNames([1]) = {'Stn';};

% clear all but WCOl, STN, DIST, aux, in
clear grplst grpnam srvlst stnlst maxgrplen; 
clear nstn ngrp nfstn;

%% STAGE 3 - Get time series data, put it in "TimSer"
%
% for each date/time of a value in the WCOL table from the spatial surveys,
% retrieve the DO and Chl values from the timeseries dataset.
%
% get the 15-min value at the nearest time to the one in WCOL, as well as 
% the hourly-mean centered on it, and the daily-mean for that day.
%
% save results in struct "TimSer" with subtables 
%   TimSer.BR.BottDO, TimSer.BR.SurfCHL, TimSer.CP.BottDO, etc
%
% the first two columns of every subtable are Date and Time, identical to 
% first two colums of WCOL. the other table columns are qh (the 15-min 
% value), hr (the hourly mean), and dy (the daily mean).
fprintf('STAGE 3/7\n');

nrow = size(WCOL,1);

% initialize tables ('fstn' = fixed site station)
nfstn = length(aux.fstnlst);
prmlst = {'BottOC';'BottOP';'SurfCHL';}; % OC = oxy conc, OP = oxy pct sat
nprm = length(prmlst);
ntab = nfstn*nprm;
tablst = cell(ntab,1);
for ifstn = 1:nfstn
    for iprm = 1:nprm
        tablst{(ifstn-1)*nprm+iprm} = sprintf('%s.%s',...
            aux.fstnlst{ifstn},prmlst{iprm});
        eval(sprintf(['TimSer.%s = array2table(nan*ones(%d,5),'...
        '''VariableNames'',{''Date'',''Time'',''qh'',''hr'',''dy''});'],...
            tablst{(ifstn-1)*nprm+iprm},nrow));
        dum = zeros(nrow,1);
        eval(sprintf('TimSer.%s.Date = datetime(dum,dum,dum);',...
            tablst{(ifstn-1)*nprm+iprm}));
        dum = cell(nrow,1);
        eval(sprintf('TimSer.%s.Time = dum;',...
            tablst{(ifstn-1)*nprm+iprm}));
        clear dum;
    end
    clear iprm;
end
clear ifstn;
% fill tables (all dn are in local time!)
for irow = 1:nrow
    fprintf('Row %d of %d\n',irow,nrow);
    filyr = WCOL.Date(irow).Year;
    dn = datenum(WCOL.Date(irow).Year,WCOL.Date(irow).Month,...
        WCOL.Date(irow).Day,...
        str2num(WCOL.Time{irow}(1:findstr(WCOL.Time{irow},':')-1)),...
        str2num(WCOL.Time{irow}(findstr(WCOL.Time{irow},':')+1:end)),0);
    for itab = 1:ntab
        % retrieve fdn and fval (whole year of TimSer)
        filnam = sprintf('%s\\%s%4dqh.mat',...
                in.nbfsmndir,tablst{itab}(1:2),filyr);
        if exist(filnam)
            eval(sprintf('load(''%s\\%s%4dqh.mat'',''qh'');',...
                in.nbfsmndir,tablst{itab}(1:2),filyr));
            fdn = qh.dnest + 1/24; % convert EST (NBFSMN) to LDT (surveys)
            if strcmp(tablst{itab}(4:end),'BottOC')
                fval = qh.dp.domgl;
            elseif strcmp(tablst{itab}(4:end),'BottOP')
                fval = qh.dp.dopc;
            elseif strcmp(tablst{itab}(4:end),'SurfCHL')
                fval = qh.sh.chl;
            end
            clear qh;
            % qh 
            cind = min(find(abs(fdn - dn)==min(abs(fdn-dn))));
            if abs(fdn(cind)-dn)<=0.25/24 
                eval(sprintf('TimSer.%s.qh(irow) = fval(cind);',...
                    tablst{itab}));
            else
                eval(sprintf('TimSer.%s.qh(irow) = nan;',...
                    tablst{itab}));
            end
            % hr
            ind = find(abs(fdn-dn)<=0.5/24);
            if ( length(ind)>=2  & ...
                    (length(find(isnan(fval(ind)))) <= 0.5*length(ind)) ) 
                eval(sprintf('TimSer.%s.hr(irow) = nanmean(fval(ind));',...
                    tablst{itab}));
            else
                eval(sprintf('TimSer.%s.hr(irow) = nan;',...
                    tablst{itab}));
            end
            % dy
            [yr,mon,dy] = datevec(dn);
            [allyr,allmon,alldy] = datevec(fdn);
            ind = find(allyr==yr & allmon==mon & alldy==dy);
            clear yr mon dy allyr allmon alldy;
            if ( length(ind)>0.5*24*4 & ...
                    (length(find(isnan(fval(ind)))) <= 0.5*length(ind)) )
                eval(sprintf('TimSer.%s.dy(irow) = nanmean(fval(ind));',...
                    tablst{itab}));
            else
                eval(sprintf('TimSer.%s.dy(irow) = nan;',...
                    tablst{itab}));
            end
            clear cind ind fdn fval;
        end
        clear filnam;
        % Date
        eval(sprintf('TimSer.%s.Date(irow) = WCOL.Date(irow);',...
                tablst{itab}));
        % Time
        eval(sprintf('TimSer.%s.Time(irow) = WCOL.Time(irow);',...
                tablst{itab}));
    end
    clear filyr dn itab;
end
clear irow;

% clear all but WCOL, STN, DIST, TimSer, aux, in
clear tablst prmlst nfstn nprm nrow ntab;  

%% STAGE 4 - Compute summary stats and ranks 
%
% Compute summary statistics and their ranks and add them to the STN table
% Useful for ordering the data in later analyses and plots
%
% Summary statistics are:
%   "AvgBotDO" average bottom DO conc 
%   "AvgDOmin" average DO conc minimum
%   "AvgSrfChl" average surface CHL 
%   "AvgChlMax" average max CHL
%
% Ranks are (ascending for DO and descending for Chl):
%  "Rnk___" for each of the above four names

fprintf('STAGE 4/7\n');

nstn = length(STN.Stn);
AvgBotDO = nan*ones(nstn,1);
AvgDOmin = nan*ones(nstn,1);
AvgSrfChl = nan*ones(nstn,1);
AvgChlMax = nan*ones(nstn,1);
for istn = 1:nstn
    ind = find(ismember(WCOL.Stn,STN.Stn{istn}));
    AvgBotDO(istn) = nanmean(WCOL.OCzmax(ind));
    AvgDOmin(istn) = nanmean(WCOL.OCmin(ind));
    AvgSrfChl(istn) = nanmean(WCOL.CHLzmin(ind));
    AvgChlMax(istn) = nanmean(WCOL.CHLmax(ind));
    clear ind;
end
clear istn nstn;
STN.AvgBotDO = AvgBotDO;
[~,Rank] = sort(AvgBotDO);
[~,Rank] = sort(Rank);
STN.RnkAvgBotDO = Rank;
clear AvgBotDO Rank;
STN.AvgDOmin = AvgDOmin;
[~,Rank] = sort(AvgDOmin);
[~,Rank] = sort(Rank);
STN.RnkAvgDOmin = Rank;
clear AvgDOmin Rank;
STN.AvgSrfChl = AvgSrfChl;
[~,Rank] = sort(AvgSrfChl,'descend');
[~,Rank] = sort(Rank);
STN.RnkAvgSrfChl = Rank;
clear AvgSrfChl Rank;
STN.AvgChlMax = AvgChlMax;
[~,Rank] = sort(AvgChlMax,'descend');
[~,Rank] = sort(Rank);
STN.RnkAvgChlMax = Rank;
clear AvgChlMax Rank;

%% STAGE 5 - Group survey stations greater/less than 4 m deep

% put previous results (for STN, WCOL, DIST, TimSer) in to "Alph" container
%       ... for "alphabetical order". 

% make new containers "Gt4", "Lt4", and "TwoGrp".

% Gt4 includes only the 57 sites with bathy depth > 4
%       In order of RnkAvgBotDO
% Lt4 includes only the 20 sites with bathy depth <= 4
%       Also in order of RnkAvgBotDO
% TwoGrp includes both of above, with Lt4 rows appended after Gt4 rows

%   * " " for the fixed stations " " 1 to 11

fprintf('STAGE 5/7\n');
 
Alph.DIST = DIST;
Alph.STN = STN;
Alph.WCOL = WCOL;
Alph.TimSer = TimSer;
Alph.aux = aux;
clear STN WCOL DIST TimSer;

% create Gt4 and Lt4
STNindLessThan4m = find(Alph.STN.zmaxMedn <= 4);
Gt4 = ordrsubset(Alph,STNindLessThan4m);
all = 1:77;
all(STNindLessThan4m) = [];
Lt4 = ordrsubset(Alph,all');
clear all STNindLessThan4m;

% create TwoGrps
ngt = length(Gt4.STN.Stn);
% STN
TwoGrp.STN = Gt4.STN;
appd = Lt4.STN;
appd.RnkAvgBotDO = appd.RnkAvgBotDO+ngt;
appd.RnkAvgDOmin = appd.RnkAvgDOmin+ngt;
appd.RnkAvgSrfChl = appd.RnkAvgSrfChl+ngt;
appd.RnkAvgChlMax = appd.RnkAvgChlMax+ngt;
TwoGrp.STN(end+1:end+length(appd.Stn),:) = appd;
clear appd ngt;
% DIST 
[~,ind] = ismember(TwoGrp.STN.Stn,Alph.DIST.Stn);
TwoGrp.DIST = Alph.DIST(ind,[1 1+ind' (length(ind)+2):(length(ind)+12)]);
clear ind;
% WCOL
TwoGrp.WCOL = Alph.WCOL;
% TimSer
TwoGrp.TimSer = Alph.TimSer;

clear TimSer WCOL STN DIST;

%% STAGE 6 - Add daily-resolution time series
%
% gather up all timeseries records, create and save daily-mean and daily
% def-dur (botDO) and daily-mean and spl-dur (surfCHL)
%
% put all results in to new table "DAILY" with these columns:
%   Date, FStn, botDOdymn, botDOdefdur1p4, botDOdefdur2p9, botDOdefdur4p8,
%           surfCHLdymn, surfCHLspldur80

fprintf('STAGE 6/7\n');

% initialize table
Date = datetime(2000,1,1);
Stn = {'DUM'};
botOCdymn = 1;
botOCdefdur1p4 = 1;
botOCdefdur2p9 = 1;
botOCdefdur4p8 = 1;
srfCHLdymn = 1;
srfCHLspldur80 = 1;
DAILY = table(Date,Stn,botOCdymn,botOCdefdur1p4,botOCdefdur2p9,...
            botOCdefdur4p8,srfCHLdymn,srfCHLspldur80);
        
% get stnlst
stns = aux.fstnlst;
nstn = length(stns);

% get chl 80th thresh values 
% N.B. THIS ASSUMES ORDER OF stn IN FILE in.chlthreshfil
%       IS SAME AS ORDER OF aux.fstnlst
load(in.chlthreshfil,'thresh');

% initial info on yrs, days
yrs = TwoGrp.WCOL.Date(1).Year:TwoGrp.WCOL.Date(end).Year;
nyr = length(yrs);
ndy = 153; % May 15 through Oct 14

% main calc loop
for iyr = 1:nyr
    fprintf('YEAR %d (%d of %d)\n',yrs(iyr),iyr,nyr);
    dnest0 = datenum(yrs(iyr),5,14);
    for istn = 1:nstn
        fprintf('    working on %s (%d of %d)\n',stns{istn},istn,nstn);
        fnam = [in.nbfsmndir stns{istn} sprintf('%d',yrs(iyr)) 'qh.mat'];
        if isfile(fnam)
            dat = load(fnam);
            for idy = 1:ndy
                if mod(idy,50)==1
                    fprintf('      working on day %d of %d\n',idy,ndy);
                end
                ind =find(dat.qh.dnest>=(dnest0+idy) & ...
                                dat.qh.dnest<(dnest0+idy+1));
                OC = dat.qh.dp.domgl(ind);
                if 100*length(isnan(OC))/length(OC) >= in.minavgpct
                    botOCdymn = nanmean(OC);
                    dif = 1.4-OC; dif(dif<0) = 0;
                    botOCdefdur1p4 = sum(dif)*0.25/24; % mg/l day
                    dif = 2.9-OC; dif(dif<0) = 0;
                    botOCdefdur2p9 = sum(dif)*0.25/24; % mg/l day
                    dif = 4.8-OC; dif(dif<0) = 0;
                    botOCdefdur4p8 = sum(dif)*0.25/24; % mg/l day
                    clear dif;
                else
                    botOCdymn = nan;
                    botOCdefdur1p4 = nan;
                    botOCdefdur2p9 = nan;
                    botOCdefdur4p8 = nan;                
                end
                clear OC;
                CHL = dat.qh.sh.chl(ind);
                if 100*length(isnan(CHL))/length(CHL) >= in.minavgpct
                    srfCHLdymn = nanmean(CHL);
                    dif = CHL - thresh(istn); dif(dif<0) = 0;
                    srfCHLspldur80 = sum(dif)*0.25/24; % ug/l day
                    clear dif;
                else
                    srfCHLdymn = nan;
                    srfCHLspldur80 = nan;
                end
                clear CHL ind;
                DAILY(end+1,:)={datetime(dnest0+idy,'ConvertFrom','datenum'),...
                    stns(istn),botOCdymn,botOCdefdur1p4,botOCdefdur2p9,...
                    botOCdefdur4p8,srfCHLdymn,srfCHLspldur80};
                clear botOC* srfCHL*;
            end
            clear dat;
        else
            DAILY(end+1,:)={datetime(dnest0+idy,'ConvertFrom','datenum'),...
                    stns(istn),nan,nan,nan,nan,nan,nan};
        end            
    end
    clear dnest0;
end
DAILY = DAILY(2:end,:);

WCOL = TwoGrp.WCOL;
DIST = TwoGrp.DIST;
STN = TwoGrp.STN;
TimSer = TwoGrp.TimSer;

aux.Alph = Alph;
aux.Gt4 = Gt4;
aux.Lt4 = Lt4;
clear Alph Gt4 Lt4;
clear TwoGrp Date fnam idy istn iyr ndy nstn nyr Stn stns thresh yrs;

%% STAGE 7 - Add "percent hypoxic area"
fprintf('STAGE 7/7\n');
t = readtable(in.PctHypAreafil,'PreserveVariableNames',1);
t = t(:,ismember(t.Properties.VariableNames, ...
    {'DATE','%2.9-4.8','% 1.4-2.9','% <1.4','SUM <4.8','% < 2.9'}));
t(1,:) = [];
ind = find(isnat(t.DATE));
t(ind,:) = [];
t.Properties.VariableNames{'DATE'} = 'Date';
t.Properties.VariableNames{'%2.9-4.8'} = 'Pct2p9to4p8';
t.Properties.VariableNames{'% 1.4-2.9'} = 'Pct1p4to2p9';
t.Properties.VariableNames{'% <1.4'} = 'PctLt1p4';
t.Properties.VariableNames{'SUM <4.8'} = 'PctLt4p8';
t.Properties.VariableNames{'% < 2.9'} = 'PctLt2p9';
t = t(:,{'Date' 'PctLt1p4' 'PctLt2p9' 'PctLt4p8' ...
    'Pct1p4to2p9' 'Pct2p9to4p8'});

PctHypArea = t;
clear t ind;

%%
readme = ...
         {'STN = Table of info about 77 spatial survey stations       ';...
          '   One station per row                                     ';... 
          '   Rows ordered by decreasing RnkAvgBotDO (lowest DO first)';...
          '        in two groups: 57 stations with median of deepest  ';...
          '        sample depth greater than 4m; then shallower 20    ';...
          '   Columns = Stn/Lat/Lon/zmaxMin/zmaxMax/zmaxStd/zBathy    ';...
          '               /AvgBotDO/RnkAvgBotDO/AvgDOmin/RnkAvgDOmin  ';...
          '               /AvgChlMax/RnkAvgChlMax                     ';...
          'WCOL = Table of info from spatial survey profiles        ';...
          '   Each row contains results from one profile              ';...                        
          '   Rows grouped by survey date, ordered by alpha stn name  ';...
          '   Columns = Date/Time/Stn/zmin/zmax/OCzmax/OCmin/zOCmin   ';...
          '               /OPzmax/OPmin/zOPmin/CHLzmin/CHLmax/zCHLmax ';...
          '               /TEMPzmin/TEMPzmax/TEMPmin/zTEMPmin/TEMPmax ';...
          '                                    /zTEMPmax/delTEMP      ';...
          '               /SALzmin/SALzmax/SALmin/zSALmin/SALmax      ';...
          '                                    /zSALmax/delSAL        ';...
          '               /SGMAzmin/SGMAzmax/SGMAmin/zSGMAmin/SGMAmax ';...
          '                                    /zSGMAmax/delSGMA      ';...
          '        (OC = DO concentration; OP = DO percent saturation)';...
          'DIST = Table (77 x 88) of distances (km) between stations  ';...
          '          (spatial survey stations and fixed site stations)';...                      ';...
          '   One spatial survey station per row                      ';...
          '   Rows ordered same as in STN                             ';...
          '   Cols 1:77: spatial survey stns (same order as rows)     ';...
          '        78:88: fixed sites PD BR CP NP GB SR MV QP PP TW MH';...
          'TimSer = struct of structs, one for each fixed site station';...
          '   Each (ex. TimSer.BR) has 3 tables: BottOC/BottOP/SurfCHL';...
          '   Each table (ex. TimSer.BR.BottOC) has rows matching WCOL';...
          '         and cols Date/Time/qh/hr/dy where qh is nearest 15';...
          '         min (qh = quarter-hour) sample to survey profile  ';...
          '         time, hr is hourly mean of 15 min samples centered';...
          '         on profile time, and dy is midnight to midnight   ';...
          '         daily mean on day of profile                      ';...
          'DAILY = Table of all 5/15-10/14 daily-mean fixed site data ';...
          '         and daily deficit-durations/surplus-durations     ';...
          '   One row per station-date                                ';...
          '   Rows grouped by station, ordered by date                ';...
          '   Cols: Date/Stn/botOCdymn/botOCdefdur1p4/botOCdefdur2p9  ';...
          '              /botOCdefdur4p8/srfCHLdymn/srfCHLspldur80    ';...
          'PctHypArea = Table of spatial surveys percent hypoxic areas';...
          '   One row per spatial survey, ordered by date             ';...
          '   Cols: Date/PctLt1p4/PctLt2p9/PctLt4p8/Pct1p4to2p9       ';...
          '                                           /Pct2p9to4p8    ';...
          'aux                                                        ';...
          '  Alph - same items as listed above (excluding PctHypArea) ';...
          '       but order of rows in WCOL and DIST are alpha by stn ';...
          '  Gt4 - same items as listed above (excluding PctHypArea)  ';...
          '       but only the 57 deeper stations                     ';...
          '  Lt4 - same items as listed above (excluding PctHypArea)  ';...
          '       but only the 20 shallower stations                  ';...
          '  fstnlst - list/ordering of fixed site stations           ';...
          '  srvlst - list of dates of spatial surveys                ';...
          '  grpnam - names of subgroupings of spatial survey stations';...
          '  grplst - list of stations in each subgrouping            ';};
        
save dat/SrvysAndTimSer DAILY DIST PctHypArea STN TimSer WCOL aux readme;

% end of module
diary off;
